@@ -250,8 +250,7 @@ _open_tty (const char *device, int argc, char **argv)
   status = mu_file_stream_create (&dev, device, MU_STREAM_APPEND|MU_STREAM_CREAT);
   if (status)
     {
-      mu_error (_("cannot open device %s: %s"),
-		device, mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "open", device, status);
       return NULL;
     }
   mu_stream_set_buffer (dev, mu_buffer_line, 0);
@@ -292,7 +291,7 @@ open_tty (const char *device, int argc, char **argv)
       int rc = mu_nullstream_create (&dev, MU_STREAM_WRITE);
       if (rc)
 	{
-	  mu_error (_("cannot open null stream: %s"), mu_strerror (rc));
+	  mu_diag_funcall (MU_DIAG_ERROR, "mu_nullstream_create", NULL, rc);
 	  dev = NULL;
 	}
     }
