@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -121,8 +121,8 @@ puts_bidi (char *string)
     {
       fb_charset_num = fribidi_parse_charset ((char*) get_charset ());
       if (fb_charset_num && frm_debug)
-	mu_error (_("fribidi failed to recognize charset `%s'"),
-		  get_charset ());
+	mu_error (_("fribidi failed to recognize charset %s"),
+		  mu_quotename (get_charset ()));
     }
   
   if (fb_charset_num == 0)
@@ -367,8 +367,8 @@ rfc2047_decode_wrapper (const char *buf, size_t buflen)
   if (rc)
     {
       if (frm_debug)
-	mu_error (_("cannot decode line `%s': %s"),
-		  buf, mu_strerror (rc));
+	mu_error (_("cannot decode line %s: %s"),
+		  mu_quotename (buf), mu_strerror (rc));
       return mu_strdup (buf);
     }
 
@@ -506,8 +506,9 @@ frm_abort (mu_mailbox_t *mbox)
     {
       mu_url_t url;
       mu_mailbox_get_url (*mbox, &url);
-      mu_error (_("could not close mailbox `%s': %s"),
-		mu_url_to_string (url), mu_strerror (status));
+      mu_error (_("could not close mailbox %s: %s"),
+		mu_quotename (mu_url_to_string (url)),
+		mu_strerror (status));
       exit (3);
     }
   
@@ -534,8 +535,8 @@ frm_scan (char *mailbox_name, frm_select_t fun, size_t *total)
   if (status != 0)
     {
       if (mailbox_name)
-	mu_error (_("could not create mailbox `%s': %s"),
-		  mailbox_name,  mu_strerror (status));
+	mu_error (_("could not create mailbox %s: %s"),
+		  mu_quotename (mailbox_name), mu_strerror (status));
       else
 	mu_error (_("could not create default mailbox: %s"),
 		  mu_strerror (status));
@@ -555,8 +556,8 @@ frm_scan (char *mailbox_name, frm_select_t fun, size_t *total)
     *total = 0;
   else if (status != 0)
     {
-      mu_error (_("could not open mailbox `%s': %s"),
-		mu_url_to_string (url), mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open",
+		       mu_url_to_string (url), status);
       mu_mailbox_destroy (&mbox);
       exit (3);
     }
@@ -575,8 +576,9 @@ frm_scan (char *mailbox_name, frm_select_t fun, size_t *total)
       status = mu_mailbox_scan (mbox, 1, total);
       if (status != 0)
 	{
-	  mu_error (_("could not scan mailbox `%s': %s"),
-		    mu_url_to_string (url), mu_strerror (status));
+	  mu_error (_("could not scan mailbox %s: %s"),
+		    mu_quotename (mu_url_to_string (url)),
+		    mu_strerror (status));
 	  frm_abort (&mbox);
 	}
       
@@ -585,8 +587,9 @@ frm_scan (char *mailbox_name, frm_select_t fun, size_t *total)
       
       if ((status = mu_mailbox_close (mbox)) != 0)
 	{
-	  mu_error (_("could not close mailbox `%s': %s"),
-		    mu_url_to_string (url), mu_strerror (status));
+	  mu_error (_("could not close mailbox %s: %s"),
+		    mu_quotename (mu_url_to_string (url)),
+		    mu_strerror (status));
 	  exit (3);
 	}
     }
