@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2021 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ imap4d_bye (int reason)
 
 static jmp_buf pipejmp;
 
-static RETSIGTYPE
+static void
 sigpipe (int sig)
 {
   longjmp (pipejmp, 1);
