@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -424,14 +424,14 @@ bodystructure (mu_message_t msg, int extension)
     mu_message_get_body (msg, &body);
     mu_body_size (body, &size);
     mu_body_lines (body, &blines);
-    io_sendf (" %s", mu_umaxtostr (0, size + blines));
+    io_sendf (" %s", mu_umaxtostr (size + blines));
   }
 
   /* If the mime type was text.  */
   if (text_plain)
     {
       /* Add the line number of the body.  */
-      io_sendf (" %s", mu_umaxtostr (0, blines));
+      io_sendf (" %s", mu_umaxtostr (blines));
     }
   else if (message_rfc822)
     {
@@ -448,7 +448,7 @@ bodystructure (mu_message_t msg, int extension)
       io_sendf (")");
       /* Size in text lines of the encapsulated message.  */
       mu_message_lines (emsg, &lines);
-      io_sendf (" %s", mu_umaxtostr (0, lines));
+      io_sendf (" %s", mu_umaxtostr (lines));
       mu_message_destroy (&emsg, NULL);
     }
 
@@ -810,7 +810,7 @@ _frt_uid (struct fetch_function_closure *ffc,
   size_t uid = 0;
 
   mu_message_get_uid (frt->msg, &uid);
-  io_sendf ("%s %s", ffc->name, mu_umaxtostr (0, uid));
+  io_sendf ("%s %s", ffc->name, mu_umaxtostr (uid));
   return RESP_OK;
 }
 
