@@ -1,5 +1,5 @@
 /* cfg.h -- general-purpose configuration file parser 
-   Copyright (C) 2007-2024 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -182,18 +182,18 @@ typedef int (*mu_cfg_section_fp) (enum mu_cfg_section_stage stage,
 
 struct mu_cfg_section
 {
-  const char *ident;              /* Section identifier */  
-  char *label;                    /* Label description */
-  mu_cfg_section_fp parser;       /* Parser function */
-  void *data;                     /* Data pointer */
-  size_t offset;                  /* Offset within target (see below) */
+  const char *ident;              /* Section identifier. */
+  char *label;                    /* Label description. */
+  mu_cfg_section_fp parser;       /* Parser function. */
+  void *data;                     /* Data pointer. */
+  size_t offset;                  /* Offset within target (see below). */
   mu_list_t /* of mu_cfg_cont */ children;
-  char *docstring;                /* Documentation string */
+  char *docstring;                /* Documentation string. */
   void *target;                   /* Actual pointer to the data. It is
 				     recomputed each time the section is
 				     reduced. */
-  char *ident_storage;            /* Storage for ident, if malloc'ed */
-  char *label_storage;            /* Same for the label */
+  char *ident_storage;            /* Storage for ident, if malloc'ed. */
+  char *label_storage;            /* Same for the label. */
 };
 
 enum mu_cfg_cont_type
@@ -206,6 +206,7 @@ struct mu_cfg_cont
 {
   enum mu_cfg_cont_type type;
   mu_refcount_t refcount;
+  char const *domain;             /* Textual domain. */
   union
   {
     const char *ident;
@@ -226,12 +227,31 @@ void mu_config_destroy_container (struct mu_cfg_cont **pcont);
 
 int mu_cfg_section_add_container (struct mu_cfg_section *sect,
 				  struct mu_cfg_cont *cont);
-int mu_cfg_section_add_params (struct mu_cfg_section *sect,
-			       struct mu_cfg_param *param);
+int mu_cfg_section_add_params_ext (struct mu_cfg_section *sect,
+				   struct mu_cfg_param *param,
+				   char const *domain);
+static inline int
+mu_cfg_section_add_params (struct mu_cfg_section *sect,
+			   struct mu_cfg_param *param)
+{
+  return mu_cfg_section_add_params_ext (sect, param, NULL);
+}
 
-
-int mu_create_canned_section (char *name, struct mu_cfg_section **psection);
-int mu_create_canned_param (char *name, struct mu_cfg_param **pparam);
+int mu_create_canned_section_ext (char *name, char const *domain,
+			      struct mu_cfg_section **psection);
+int mu_create_canned_param_ext (char *name, char const *domain,
+				struct mu_cfg_param **pparam);
+static inline int mu_create_canned_section (char *name,
+					    struct mu_cfg_section **psection)
+{
+  return mu_create_canned_section_ext (name, NULL, psection);
+}
+static inline int mu_create_canned_param (char *name, 
+					  struct mu_cfg_param **pparam)
+{
+  return mu_create_canned_param_ext (name, NULL, pparam);
+}
+  
 struct mu_cfg_cont *mu_get_canned_container (const char *name);
 
 int mu_cfg_create_node_list (mu_list_t *plist);
@@ -248,16 +268,19 @@ int mu_config_container_register_section (struct mu_cfg_cont **proot,
 					  const char *label,
 					  mu_cfg_section_fp parser,
 					  struct mu_cfg_param *param,
+					  char const *domain,
 					  struct mu_cfg_section **psection);
 int mu_config_root_register_section (const char *parent_path,
 				     const char *ident,
 				     const char *label,
 				     mu_cfg_section_fp parser,
-				     struct mu_cfg_param *param);
+				     struct mu_cfg_param *param,
+				     char const *domain);
 
 int mu_config_register_plain_section (const char *parent_path,
 				      const char *ident,
-				      struct mu_cfg_param *params);
+				      struct mu_cfg_param *params,
+				      char const *domain);
 
   
 extern int mu_cfg_parser_verbose;
