@@ -1,5 +1,5 @@
 /* opt.h -- general-purpose command line option parser 
-   Copyright (C) 2016-2023 Free Software Foundation, Inc.
+   Copyright (C) 2016-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -31,6 +31,7 @@ struct mu_cli_capa
   struct mu_cfg_param *cfg;
   mu_cfg_section_fp parser;
   mu_cli_capa_commit_fp commit;
+  char const *domain;
 };
 
 void mu_cli_capa_init (void);
@@ -40,20 +41,21 @@ void mu_cli_capa_extend_settings (char const *name, mu_list_t opts,
 
 struct mu_cli_setup
 {
-  struct mu_option **optv;     /* Command-line options */
-  struct mu_cfg_param *cfg;    /* Configuration parameters */
-  char *prog_doc;              /* Program documentation string */
-  char *prog_args;             /* Program arguments string */
-  char const **prog_alt_args;  /* Alternative arguments string */
+  struct mu_option **optv;     /* Command-line options. */
+  struct mu_cfg_param *cfg;    /* Configuration parameters. */
+  char *prog_doc;              /* Program documentation string. */
+  char *prog_args;             /* Program arguments string. */
+  char const **prog_alt_args;  /* Alternative arguments string. */
   char *prog_extra_doc;        /* Extra documentation.  This will be
 				  displayed after options. */
-  int ex_usage;                /* If not 0, exit code on usage errors */
+  int ex_usage;                /* If not 0, exit code on usage errors. */
   int ex_config;               /* If not 0, exit code on configuration
-				  errors */
-  int inorder:1;               /* Don't permute options and arguments */
+				  errors. */
+  int inorder:1;               /* Don't permute options and arguments. */
   int server:1;                /* This is a server: don't read per-user
-				  configuration files */
+				  configuration files. */
   void (*prog_doc_hook) (mu_stream_t);
+  char const *domain;          /* Translation domain. */
 };
 
 extern const char mu_version_copyright[];
