@@ -1,5 +1,5 @@
 extern int display_stream_mailcap (const char *ident, mu_stream_t stream,
 				   mu_header_t hdr, const char *no_ask,
 				   int interactive, int dry_run,
-				   int debug_level);
+				   mu_debug_handle_t dh);
 
