@@ -131,7 +131,7 @@ cb_text_type (void *data, mu_config_value_t *val)
 
 static struct mu_cfg_param mime_param[] = {
   { "text-type", mu_cfg_callback, NULL, 0, cb_text_type,
-    N_("Define textual mime types."),
+    N_("Define textual MIME types."),
     N_("arg: pattern or list of patterns") },
   { NULL }
 };
@@ -170,7 +170,7 @@ charset_setup (mu_stream_t *pstr, mu_content_type_t ct, char const *charset)
 				   (char**) argv);
       if (rc)
 	{
-	  mu_error (_("can't convert from charset %s to %s: %s"),
+	  mu_error (_("cannot convert from charset %s to %s: %s"),
 		    param->value, charset, mu_strerror (rc));
 	  return rc;
 	}
