@@ -75,8 +75,10 @@ void
 mu_tcpwrapper_cfg_init ()
 {
   struct mu_cfg_section *section;
-  mu_create_canned_section ("tcp-wrappers", &section);
-  mu_cfg_section_add_params (section, tcpwrapper_param);
+  mu_create_canned_section_ext ("tcp-wrappers", DEFAULT_TEXT_DOMAIN,
+				&section);
+  mu_cfg_section_add_params_ext (section, tcpwrapper_param,
+				 DEFAULT_TEXT_DOMAIN);
 }
 
 #else
