@@ -40,8 +40,8 @@ mu_remove_file (const char *path)
   if (stat (path, &st))
     {
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("can't stat file %s: %s"),
-		 path, mu_strerror (errno)));
+		(_("%s(%s) failed: %s"),
+		 "stat", path, mu_strerror (errno)));
       return errno;
     }
 
@@ -51,7 +51,7 @@ mu_remove_file (const char *path)
     {
       rc = errno;
       mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		(_("can't unlink file %s: %s"),
+		(_("cannot unlink file %s: %s"),
 		 path, mu_strerror (rc)));
     }
 
@@ -221,8 +221,8 @@ removedir (const char *path)
 	  if (rc == ENOENT)
 	    continue;
 	  mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-		    (_("can't lstat file %s: %s"),
-		     ent->name, mu_strerror (rc)));
+		    (_("%s(%s) failed: %s"),
+		     "lstat", ent->name, mu_strerror (rc)));
 	  break;
 	}
 
@@ -258,7 +258,7 @@ removedir (const char *path)
 	  if (rc)
 	    {
 	      mu_debug (MU_DEBCAT_STREAM, MU_DEBUG_ERROR,
-			(_("can't remove %s: %s"),
+			(_("cannot remove %s: %s"),
 			 ent->name, mu_strerror (rc)));
 	    }
 	}
