@@ -121,6 +121,7 @@
 #include <mailutils/stdstream.h>
 #include <mailutils/cidr.h>
 #include <mailutils/yyloc.h>
+#include <mailutils/cstr.h>
 
 int mu_cfg_parser_verbose;
 static mu_list_t /* of mu_cfg_node_t */ parse_node_list; 
@@ -248,7 +249,7 @@ mu_cfg_create_node_list (mu_list_t *plist)
 }
 
 
-#line 252 "parser.c"
+#line 253 "parser.c"
 
 # ifndef YY_CAST
 #  ifdef __cplusplus
@@ -695,10 +696,10 @@ static const yytype_int8 yytranslate[] =
 /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_int16 yyrline[] =
 {
-       0,   202,   202,   208,   213,   221,   222,   225,   234,   241,
-     251,   255,   258,   261,   296,   306,   312,   317,   322,   329,
-     330,   331,   334,   353,   358,   365,   369,   375,   380,   387,
-     388
+       0,   203,   203,   209,   214,   222,   223,   226,   235,   242,
+     252,   256,   259,   262,   297,   307,   313,   318,   323,   330,
+     331,   332,   335,   354,   359,   366,   370,   376,   381,   388,
+     389
 };
 #endif
 
@@ -1392,56 +1393,56 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* input: stmtlist  */
-#line 203 "parser.y"
+#line 204 "parser.y"
           {
 	    parse_node_list = (yyvsp[0].nodelist);
 	  }
-#line 1400 "parser.c"
+#line 1401 "parser.c"
     break;
 
   case 3: /* stmtlist: stmt  */
-#line 209 "parser.y"
+#line 210 "parser.y"
           {
 	    mu_cfg_create_node_list (&(yyval.nodelist));
 	    mu_list_append ((yyval.nodelist), (yyvsp[0].pnode));
 	  }
-#line 1409 "parser.c"
+#line 1410 "parser.c"
     break;
 
   case 4: /* stmtlist: stmtlist stmt  */
-#line 214 "parser.y"
+#line 215 "parser.y"
           {
 	    mu_list_append ((yyvsp[-1].nodelist), (yyvsp[0].pnode));
 	    (yyval.nodelist) = (yyvsp[-1].nodelist);
 	    debug_print_node ((yyvsp[0].pnode));
 	  }
-#line 1419 "parser.c"
+#line 1420 "parser.c"
     break;
 
   case 7: /* simple: ident vallist ';'  */
-#line 226 "parser.y"
+#line 227 "parser.y"
           {
 	    struct mu_locus_range lr;
 	    lr.beg = (yylsp[-2]).beg;
 	    lr.end = (yylsp[0]).end;
 	    (yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_param, &lr, (yyvsp[-2].string), (yyvsp[-1].pvalue), NULL);
 	  }
-#line 1430 "parser.c"
+#line 1431 "parser.c"
     break;
 
   case 8: /* block: ident tag '{' '}' opt_sc  */
-#line 235 "parser.y"
+#line 236 "parser.y"
           {
 	    struct mu_locus_range lr;
 	    lr.beg = (yylsp[-4]).beg;
 	    lr.end = (yylsp[0]).end;
 	    (yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_statement, &lr, (yyvsp[-4].string), (yyvsp[-3].pvalue), NULL);
 	  }
-#line 1441 "parser.c"
+#line 1442 "parser.c"
     break;
 
   case 9: /* block: ident tag '{' stmtlist '}' opt_sc  */
-#line 242 "parser.y"
+#line 243 "parser.y"
           {
 	    struct mu_locus_range lr;
 	    lr.beg = (yylsp[-5]).beg;
@@ -1449,19 +1450,19 @@ yyreduce:
 	    (yyval.pnode) = mu_cfg_alloc_node (mu_cfg_node_statement, &lr, (yyvsp[-5].string), (yyvsp[-4].pvalue), (yyvsp[-2].nodelist));
 	    mu_list_foreach ((yyvsp[-2].nodelist), _node_set_parent, (yyval.pnode));
 	  }
-#line 1453 "parser.c"
+#line 1454 "parser.c"
     break;
 
   case 11: /* tag: %empty  */
-#line 255 "parser.y"
+#line 256 "parser.y"
           {
 	    (yyval.pvalue) = NULL;
 	  }
-#line 1461 "parser.c"
+#line 1462 "parser.c"
     break;
 
   case 13: /* vallist: vlist  */
-#line 262 "parser.y"
+#line 263 "parser.y"
           {
 	    size_t n = 0;
 	    mu_list_count((yyvsp[0].list), &n);
@@ -1494,60 +1495,60 @@ yyreduce:
 	      }
 	    mu_list_destroy (&(yyvsp[0].list));
 	  }
-#line 1498 "parser.c"
+#line 1499 "parser.c"
     break;
 
   case 14: /* vlist: value  */
-#line 297 "parser.y"
+#line 298 "parser.y"
           {
 	    int rc = mu_list_create (&(yyval.list));
 	    if (rc)
 	      {
-		mu_error (_("cannot create list: %s"), mu_strerror (rc));
+		mu_diag_funcall (MU_DIAG_ERROR, "mu_list_create", NULL, rc);
 		abort ();
 	      }
 	    mu_list_append ((yyval.list), config_value_dup (&(yyvsp[0].value))); /* FIXME */
 	  }
-#line 1512 "parser.c"
+#line 1513 "parser.c"
     break;
 
   case 15: /* vlist: vlist value  */
-#line 307 "parser.y"
+#line 308 "parser.y"
           {
 	    mu_list_append ((yyvsp[-1].list), config_value_dup (&(yyvsp[0].value)));
 	  }
-#line 1520 "parser.c"
+#line 1521 "parser.c"
     break;
 
   case 16: /* value: string  */
-#line 313 "parser.y"
+#line 314 "parser.y"
           {
 	      (yyval.value).type = MU_CFG_STRING;
 	      (yyval.value).v.string = (yyvsp[0].string);
 	  }
-#line 1529 "parser.c"
+#line 1530 "parser.c"
     break;
 
   case 17: /* value: list  */
-#line 318 "parser.y"
+#line 319 "parser.y"
           {
 	      (yyval.value).type = MU_CFG_LIST;
 	      (yyval.value).v.list = (yyvsp[0].list);
 	  }
-#line 1538 "parser.c"
+#line 1539 "parser.c"
     break;
 
   case 18: /* value: MU_TOK_MSTRING  */
-#line 323 "parser.y"
+#line 324 "parser.y"
           {
 	      (yyval.value).type = MU_CFG_STRING;
 	      (yyval.value).v.string = (yyvsp[0].string);
 	  }
-#line 1547 "parser.c"
+#line 1548 "parser.c"
     break;
 
   case 22: /* slist: slist0  */
-#line 335 "parser.y"
+#line 336 "parser.y"
           {
 	    mu_iterator_t itr;
 	    mu_list_get_iterator ((yyvsp[0].list), &itr);
@@ -1564,63 +1565,63 @@ yyreduce:
 	    mu_iterator_destroy (&itr);
 	    mu_list_destroy(&(yyvsp[0].list));
 	  }
-#line 1568 "parser.c"
+#line 1569 "parser.c"
     break;
 
   case 23: /* slist0: MU_TOK_QSTRING  */
-#line 354 "parser.y"
+#line 355 "parser.y"
           {
 	    mu_list_create (&(yyval.list));
 	    mu_list_append ((yyval.list), (yyvsp[0].string));
 	  }
-#line 1577 "parser.c"
+#line 1578 "parser.c"
     break;
 
   case 24: /* slist0: slist0 MU_TOK_QSTRING  */
-#line 359 "parser.y"
+#line 360 "parser.y"
           {
 	    mu_list_append ((yyvsp[-1].list), (yyvsp[0].string));
 	    (yyval.list) = (yyvsp[-1].list);
 	  }
-#line 1586 "parser.c"
+#line 1587 "parser.c"
     break;
 
   case 25: /* list: '(' values ')'  */
-#line 366 "parser.y"
+#line 367 "parser.y"
           {
 	      (yyval.list) = (yyvsp[-1].list);
 	  }
-#line 1594 "parser.c"
+#line 1595 "parser.c"
     break;
 
   case 26: /* list: '(' values ',' ')'  */
-#line 370 "parser.y"
+#line 371 "parser.y"
           {
 	      (yyval.list) = (yyvsp[-2].list);
 	  }
-#line 1602 "parser.c"
+#line 1603 "parser.c"
     break;
 
   case 27: /* values: value  */
-#line 376 "parser.y"
+#line 377 "parser.y"
           {
 	    mu_list_create (&(yyval.list));
 	    mu_list_append ((yyval.list), config_value_dup (&(yyvsp[0].value)));
 	  }
-#line 1611 "parser.c"
+#line 1612 "parser.c"
     break;
 
   case 28: /* values: values ',' value  */
-#line 381 "parser.y"
+#line 382 "parser.y"
           {
 	    mu_list_append ((yyvsp[-2].list), config_value_dup (&(yyvsp[0].value)));
 	    (yyval.list) = (yyvsp[-2].list);
 	  }
-#line 1620 "parser.c"
+#line 1621 "parser.c"
     break;
 
 
-#line 1624 "parser.c"
+#line 1625 "parser.c"
 
       default: break;
     }
@@ -1818,7 +1819,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 392 "parser.y"
+#line 393 "parser.y"
 
 
 void
@@ -1946,8 +1947,10 @@ do_include (const char *name, struct mu_cfg_parse_hints *hints,
 	  else
 	    {
 	      mu_diag_at_locus_range (MU_LOG_WARNING, loc,
-				      _("ignoring `include': directory argument is allowed only from the top-level configuration file"));
-
+				      _("ignoring 'include': "
+					"directory argument is allowed "
+					"only in the top-level "
+					"configuration file"));
 	    }
 	}
       else
@@ -2020,7 +2023,8 @@ mu_cfg_tree_postprocess (mu_cfg_tree_t *tree, struct mu_cfg_parse_hints *hints)
 		  else
 		    {
 		      mu_diag_at_locus_range (MU_LOG_ERROR, &node->locus,
-					      _("argument to `program' is not a string"));
+					      _("argument to 'program' "
+						"is not a string"));
 		      mu_cfg_error_count++;
 		      mu_iterator_ctl (itr, mu_itrctl_delete, NULL);
 		    }
@@ -2028,7 +2032,9 @@ mu_cfg_tree_postprocess (mu_cfg_tree_t *tree, struct mu_cfg_parse_hints *hints)
 	      else
 		{
 		  mu_diag_at_locus_range (MU_LOG_WARNING, &node->locus,
-					  _("ignoring `program' block: not located in top-level configuration file"));
+					  _("ignoring 'program' block: "
+					    "not located in top-level "
+					    "configuration file"));
 		}
 	    }
 	}
@@ -2052,7 +2058,7 @@ mu_cfg_tree_postprocess (mu_cfg_tree_t *tree, struct mu_cfg_parse_hints *hints)
 	  else
 	    {
 	      mu_diag_at_locus_range (MU_LOG_ERROR, &node->locus,
-				_("argument to `include' is not a string"));
+				_("argument to 'include' is not a string"));
 	      mu_cfg_error_count++;
 	    }
 	  
@@ -2322,7 +2328,7 @@ parse_param (struct scan_tree_data *sdata, const mu_cfg_node_t *node)
   if (!param)
     {
       mu_diag_at_locus_range (MU_LOG_ERROR, &node->locus,
-			      _("unknown keyword `%s'"),
+			      _("unknown keyword: %s"),
 			      node->tag);
       mu_cfg_error_count++;
       return 1;
@@ -2416,7 +2422,7 @@ _scan_tree_helper (const mu_cfg_node_t *node, void *data)
 	  if (mu_cfg_parser_verbose)
 	    {
 	      mu_diag_at_locus_range (MU_LOG_WARNING, &node->locus,
-				      _("unknown section `%s'"),
+				      _("unknown section: %s"),
 				      node->tag);
 	    }
 	  return MU_CFG_ITER_SKIP;
@@ -2727,7 +2733,7 @@ split_cfg_path (const char *path, int *pargc, char ***pargv)
       
       if (mu_wordsplit (path, &ws, MU_WRDSF_DEFFLAGS|MU_WRDSF_DELIM))
 	{
-	  mu_error (_("cannot split line `%s': %s"), path,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (path),
 		    mu_wordsplit_strerror (&ws));
 	  mu_wordsplit_free (&ws);
 	  return errno;
@@ -2803,7 +2809,7 @@ parse_label (const char *str)
       if (mu_wordsplit_len (str + 1, len - 2, &ws,
 			    MU_WRDSF_DEFFLAGS|MU_WRDSF_DELIM|MU_WRDSF_WS))
 	{
-	  mu_error (_("cannot split line `%s': %s"), str,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (str),
 		    mu_wordsplit_strerror (&ws));
 	  return NULL;
 	}
@@ -2825,7 +2831,7 @@ parse_label (const char *str)
     {      
       if (mu_wordsplit (str, &ws, MU_WRDSF_DEFFLAGS))
 	{
-	  mu_error (_("cannot split line `%s': %s"), str,
+	  mu_error (_("cannot split line %s: %s"), mu_quotename (str),
 		    mu_wordsplit_strerror (&ws));
 	  return NULL;
 	}
