@@ -310,7 +310,7 @@ parse_spec (const char *spec)
 			    MU_WRDSF_DELIM|MU_WRDSF_WS|
 			    MU_WRDSF_NOVAR|MU_WRDSF_NOCMD))
 	    {
-	      mu_error (_("cannot split line `%s': %s"), p + 1,
+	      mu_error (_("cannot split line %s: %s"), mu_quotename (p + 1),
 			mu_wordsplit_strerror (&ws));
 	      return;
 	    }
@@ -343,7 +343,7 @@ parse_spec (const char *spec)
 
 		  if (mu_debug_level_from_string (s, &n, &end))
 		    {
-		      mu_error (_("unknown level `%s'"), s);
+		      mu_error (_("unknown level: %s"), s);
 		      continue;
 		    }
 		  else if (*end == '-')
@@ -353,7 +353,7 @@ parse_spec (const char *spec)
 		      s = end + 1;
 		      if (mu_debug_level_from_string (s, &l, &end))
 			{
-			  mu_error (_("unknown level `%s'"), s);
+			  mu_error (_("unknown level: %s"), s);
 			  continue;
 			}
 		      else if (*end)
@@ -399,7 +399,7 @@ mu_debug_parse_spec (const char *spec)
 		    MU_WRDSF_DELIM|MU_WRDSF_WS|
 		    MU_WRDSF_NOVAR|MU_WRDSF_NOCMD))
     {
-      mu_error (_("cannot split line `%s': %s"), spec,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (spec),
 		mu_wordsplit_strerror (&ws));
     }
   else
