@@ -266,7 +266,7 @@ _crlfdot_encoder (void *xd,
 	    {
 	      if (i == 0)
 		{
-		  iobuf->osize = 2;
+		  iobuf->osize += 2;
 		  return mu_filter_moreoutput;
 		}
 	      break;
@@ -285,7 +285,7 @@ _crlfdot_encoder (void *xd,
 	    {
 	      if (i == 0)
 		{
-		  iobuf->osize = 2;
+		  iobuf->osize += 2;
 		  return mu_filter_moreoutput;
 		}
 	      break;
