@@ -294,7 +294,7 @@ save_fcc (mu_message_t msg)
 	  if (mu_wordsplit (fcc, &ws,
 			    MU_WRDSF_DEFFLAGS|MU_WRDSF_DELIM|MU_WRDSF_WS))
 	    {
-	      mu_error (_("cannot split line `%s': %s"), fcc,
+	      mu_error (_("cannot split line %s: %s"), mu_quotename (fcc),
 			mu_wordsplit_strerror (&ws));
 	      continue;
 	    }
