@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2007-2024 Free Software Foundation, Inc.
+   Copyright (C) 2007-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -161,6 +161,12 @@ sieve_pipe (mu_sieve_machine_t mach, int test)
   while (0);
 
   result = mu_stream_close (pstr);
+  if (rc == 0 && !test)
+    {
+      rc = result;
+      error_diag = _("error closing program stream");
+      error_arg = cmd;
+    }
 
   if (rc)
     {
