@@ -153,8 +153,8 @@ mu_i_sv_lint_command (struct mu_sieve_machine *mach,
 	  if (!tag)
 	    {
 	      mu_diag_at_locus_range (MU_LOG_ERROR, &val->locus, 
-				_("invalid tag name `%s' for `%s'"),
-				val->v.string, reg->name);
+				      _("invalid tag name %s for '%s'"),
+				      mu_quotename (val->v.string), reg->name);
 	      mu_i_sv_error (mach);
 	      err = 1;
 	      break;
@@ -191,13 +191,13 @@ mu_i_sv_lint_command (struct mu_sieve_machine *mach,
 	      if (val->type != tag->argtype)
 		{
 		  mu_diag_at_locus_range (MU_LOG_ERROR, &val->locus, 
-				    _("type mismatch in argument to "
-				      "tag `%s'"),
-				    tag->name);
+					  _("type mismatch in argument"
+					    " to tag '%s'"),
+					  tag->name);
 		  mu_diag_at_locus_range (MU_LOG_ERROR, &val->locus, 
-				    _("expected %s but passed %s"),
-				    mu_sieve_type_str (tag->argtype),
-				    mu_sieve_type_str (val->type));
+					  _("expected %s but passed %s"),
+					  mu_sieve_type_str (tag->argtype),
+					  mu_sieve_type_str (val->type));
 		  mu_i_sv_error (mach);
 		  err = 1;
 		  break;
@@ -242,7 +242,7 @@ mu_i_sv_lint_command (struct mu_sieve_machine *mach,
 	      else
 		{
 		  mu_diag_at_locus_range (MU_LOG_ERROR, &mach->locus, 
-				    _("too many arguments in call to `%s'"),
+				    _("too many arguments in call to '%s'"),
 				    reg->name);
 		  mu_i_sv_error (mach);
 		  err = 1;
@@ -257,7 +257,7 @@ mu_i_sv_lint_command (struct mu_sieve_machine *mach,
 	      else
 		{
 		  mu_diag_at_locus_range (MU_LOG_ERROR, &val->locus, 
-				    _("type mismatch in argument %lu to `%s'"),
+				    _("type mismatch in argument %lu to '%s'"),
 				    (unsigned long) (exp_arg - reg->v.command.req_args + 1),
 				    reg->name);
 		  mu_diag_at_locus_range (MU_LOG_ERROR, &val->locus, 
@@ -276,7 +276,7 @@ mu_i_sv_lint_command (struct mu_sieve_machine *mach,
   if (!err && !opt_args && *exp_arg != SVT_VOID)
     {
       mu_diag_at_locus_range (MU_LOG_ERROR, &mach->locus, 
-			      _("too few arguments in call to `%s'"),
+			      _("too few arguments in call to '%s'"),
 			      reg->name);
       mu_i_sv_error (mach);
       err = 1;
