@@ -69,6 +69,7 @@ regunload (void *data)
 {
   mu_sieve_registry_t *reg = data;
   mu_sieve_unload_ext (reg->handle);
+  free (reg);
 }
 
 static int
@@ -96,7 +97,16 @@ mu_i_sv_registry_add (mu_sieve_machine_t mach, const char *name,
       mu_list_set_destroy_item (mach->registry, regunload);
       mu_list_set_comparator (mach->registry, regcmp);
     }
-  reg = mu_sieve_malloc (mach, sizeof (*reg));
+  /*
+   * NOTE: Don't use mu_sieve_malloc here.  See the comment
+   * to function mu_sieve_machine_destroy in sieve-gram.y for details.
+   */
+  reg = malloc (sizeof (*reg));
+  if (!reg)
+    {
+      mu_sieve_error (mach, "%s", mu_strerror (errno));
+      mu_sieve_abort (mach);
+    }
   reg->name = name;
   reg->handle = NULL;
   reg->required = 0;
@@ -114,7 +124,7 @@ mu_sieve_registry_add (mu_sieve_machine_t mach, const char *name)
   int rc = mu_i_sv_registry_add (mach, name, &reg);
   if (rc)
     {
-      mu_sieve_error (mach, _("can't add to sieve registry: %s"),
+      mu_sieve_error (mach, _("cannot add to sieve registry: %s"),
 		      mu_strerror (rc));
       mu_sieve_abort (mach);
     }
