@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -301,7 +301,8 @@ mu_sieve_mailbox (mu_sieve_machine_t mach, mu_mailbox_t mbox)
   mach->msgno = 0;
   rc = mu_mailbox_scan (mbox, 1, &total);
   if (rc)
-    mu_sieve_error (mach, _("mu_mailbox_scan: %s"), mu_strerror (errno));
+    mu_sieve_error (mach, _("%s failed: %s"), "mu_mailbox_scan",
+		    mu_strerror (errno));
 
   mu_observable_detach (observable, observer);
   mu_observer_destroy (&observer, mach);
