@@ -217,7 +217,8 @@ mu_sieve_error (mu_sieve_machine_t mach, const char *fmt, ...)
   va_list ap;
   
   va_start (ap, fmt);
-  mu_stream_printf (mach->errstream, "\033s<%d>", MU_LOG_ERROR);
+  mu_stream_printf (mach->errstream, "\033s<%d>\033O<%d>", MU_LOG_ERROR,
+		    MU_LOGMODE_LOCUS);
   if (mach->identifier)
     mu_stream_printf (mach->errstream, "%s: ", mach->identifier);
   mu_stream_vprintf (mach->errstream, fmt, ap);
