@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2024 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -37,7 +37,7 @@ _imap_list_free (void *ptr)
     case imap_eltype_string:
       free (elt->v.string);
       break;
-      
+
     case imap_eltype_list:
       mu_list_destroy (&elt->v.list);
     }
@@ -102,7 +102,7 @@ static char *
 parsebuf_gettok (struct parsebuf *pb)
 {
   char *p;
-  
+
   if (pb->pb_count == 0)
     return NULL;
   p = *pb->pb_arr;
@@ -163,14 +163,14 @@ _parse_element (struct parsebuf *pb)
     return NULL;
 
   tok = parsebuf_gettok (pb);
-  
+
   if (!tok)
     {
       if (pb->pb_inlist)
 	parsebuf_seterr (pb, MU_ERR_PARSE);
       return NULL;
     }
-  
+
   if (IS_LBRACE (tok))
     {
       tok = parsebuf_peek (pb);
@@ -179,7 +179,7 @@ _parse_element (struct parsebuf *pb)
 	  parsebuf_seterr (pb, MU_ERR_PARSE);
 	  return NULL;
 	}
-      
+
       if (IS_RBRACE (tok))
 	{
 	  parsebuf_gettok (pb);
@@ -274,10 +274,25 @@ _mu_imap_list_element_is_nil (struct imap_list_element *elt)
 }
 
 struct imap_list_element *
-_mu_imap_list_at (mu_list_t list, int idx)
+_mu_imap_list_at (mu_list_t list, ssize_t idx)
 {
   struct imap_list_element *arg;
-  int rc = mu_list_get (list, idx, (void*) &arg);
+  int rc;
+
+  if (idx < 0)
+    {
+      size_t n;
+      rc = mu_list_count (list, &n);
+      if (rc || -idx > n)
+	{
+	  mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
+		    ("cannot get number of list elements: %s", mu_strerror (rc)));
+	  return NULL;
+	}
+      idx += n;
+    }
+
+  rc = mu_list_get (list, idx, (void*) &arg);
   if (rc)
     {
       mu_debug (MU_DEBCAT_MAILBOX, MU_DEBUG_ERROR,
@@ -288,7 +303,7 @@ _mu_imap_list_at (mu_list_t list, int idx)
 }
 
 int
-_mu_imap_list_nth_element_is_string (mu_list_t list, size_t n,
+_mu_imap_list_nth_element_is_string (mu_list_t list, ssize_t n,
 				     const char *str)
 {
   struct imap_list_element *elt = _mu_imap_list_at (list, n);
@@ -297,12 +312,10 @@ _mu_imap_list_nth_element_is_string (mu_list_t list, size_t n,
 }
 
 int
-_mu_imap_list_nth_element_is_string_ci (mu_list_t list, size_t n,
-				     	const char *str)
+_mu_imap_list_nth_element_is_string_ci (mu_list_t list, ssize_t n,
+					const char *str)
 {
   struct imap_list_element *elt = _mu_imap_list_at (list, n);
   return elt && elt->type == imap_eltype_string &&
 	 mu_c_strcasecmp (elt->v.string, str) == 0;
 }
-
-
