@@ -32,6 +32,7 @@
 #include <mailutils/stream.h>
 #include <mailutils/sys/smtp.h>
 #include <mailutils/gsasl.h>
+#include <mailutils/cstr.h>
 #include <gsasl.h>
 
 static int
@@ -53,7 +54,7 @@ get_implemented_mechs (Gsasl *ctx, mu_list_t *plist)
 
   if (mu_wordsplit (listmech, &ws, MU_WRDSF_DEFFLAGS))
     {
-      mu_error (_("cannot split line `%s': %s"), listmech,
+      mu_error (_("cannot split line %s: %s"), mu_quotename (listmech),
 		mu_wordsplit_strerror (&ws));
       rc = errno;
     }
