@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2009-2023 Free Software Foundation, Inc.
+   Copyright (C) 2009-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,20 +35,27 @@ struct mailvar_symbol
   int flags;
   char *descr;
   int (*handler) (enum mailvar_cmd, struct mailvar_variable *);
+  int (*init) (struct mailvar_variable *);
 };
 
 mu_list_t mailvar_list = NULL;
 
+static int init_decode_fallback (struct mailvar_variable *);
 static int set_decode_fallback (enum mailvar_cmd cmd,
 				struct mailvar_variable *);
 static int set_replyregex (enum mailvar_cmd cmd,
 			   struct mailvar_variable *);
+static int init_screen (struct mailvar_variable *);
 static int set_screen (enum mailvar_cmd cmd,
 		       struct mailvar_variable *);
+static int init_columns (struct mailvar_variable *);
+
 static int set_verbose (enum mailvar_cmd cmd,
 			struct mailvar_variable *);
+static int init_debug (struct mailvar_variable *var);
 static int set_debug (enum mailvar_cmd cmd,
 		      struct mailvar_variable *);
+static int init_folder (struct mailvar_variable *var);
 static int set_folder (enum mailvar_cmd cmd,
 		       struct mailvar_variable *);
 static int set_headline (enum mailvar_cmd,
@@ -57,6 +64,8 @@ static int set_outfilename (enum mailvar_cmd,
 			    struct mailvar_variable *);
 static int set_escape (enum mailvar_cmd,
 		       struct mailvar_variable *);
+static int init_sendmail (struct mailvar_variable *var);
+static int init_pid (struct mailvar_variable *var);
 
 struct mailvar_symbol mailvar_tab[] =
   {
@@ -103,7 +112,8 @@ struct mailvar_symbol mailvar_tab[] =
       N_("default shell command for pipe") },
     { { mailvar_name_columns, },
       MAILVAR_TYPEMASK (mailvar_type_number),
-      N_("number of columns on terminal screen") },
+      N_("number of columns on terminal screen"),
+      NULL, init_columns },
     { { mailvar_name_crt, },
       MAILVAR_TYPEMASK (mailvar_type_number) |
       MAILVAR_TYPEMASK (mailvar_type_boolean),
@@ -112,17 +122,17 @@ struct mailvar_symbol mailvar_tab[] =
 	 "screen to compute the threshold") },
     { { mailvar_name_datefield, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
-      N_("get date from the `Date:' header, instead of the envelope") },
+      N_("get date from the 'Date:' header, instead of the envelope") },
     { { mailvar_name_debug, },
       MAILVAR_TYPEMASK (mailvar_type_string) |
 	MAILVAR_TYPEMASK (mailvar_type_boolean),
       N_("set Mailutils debug level"),
-      set_debug },
+      set_debug, init_debug },
     { { mailvar_name_decode_fallback, },
       MAILVAR_TYPEMASK (mailvar_type_string),
       N_("how to represent characters that cannot be rendered using the "
 	 "current character set"),
-      set_decode_fallback },
+      set_decode_fallback, init_decode_fallback },
     { { mailvar_name_dot, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
       N_("input message is terminated with a dot alone on a line") },
@@ -142,17 +152,17 @@ struct mailvar_symbol mailvar_tab[] =
     { { mailvar_name_folder, },
       MAILVAR_TYPEMASK (mailvar_type_string),
       N_("folder directory name"),
-      set_folder },
+      set_folder, init_folder },
     { { mailvar_name_fromfield, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
-      N_("get sender address from the `From:' header, instead of "
+      N_("get sender address from the 'From:' header, instead of "
 	 "the envelope") },
     { { mailvar_name_gnu_last_command, },
       MAILVAR_TYPEMASK (mailvar_type_string) | MAILVAR_RDONLY,
       N_("last executed command line") },
     { { mailvar_name_header, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
-      N_("run the `headers' command after entering interactive mode") },
+      N_("run the 'headers' command after entering interactive mode") },
     { { mailvar_name_headline, },
       MAILVAR_TYPEMASK (mailvar_type_string),
       N_("format string to use for the header summary"),
@@ -252,10 +262,11 @@ struct mailvar_symbol mailvar_tab[] =
     { { mailvar_name_screen, },
       MAILVAR_TYPEMASK (mailvar_type_number),
       N_("number of lines on terminal screen"),
-      set_screen },
+      set_screen, init_screen },
     { { mailvar_name_sendmail, },
       MAILVAR_TYPEMASK (mailvar_type_string),
-      N_("URL of the mail transport agent") },
+      N_("URL of the mail transport agent"),
+      NULL, init_sendmail },
     /* FIXME: Not yet used. */
     { { mailvar_name_sendwait, },
       MAILVAR_TYPEMASK (mailvar_type_boolean) | MAILVAR_HIDDEN, NULL },
@@ -267,14 +278,14 @@ struct mailvar_symbol mailvar_tab[] =
       N_("name of the signature file for use with the ~A command") },
     { { mailvar_name_showenvelope, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
-      N_("`print' command includes the SMTP envelope in its output") },
+      N_("'print' command includes the SMTP envelope in its output") },
     { { mailvar_name_showto, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
       N_("if the message was sent by me, print its recipient address "
 	 "in the header summary") },
     { { mailvar_name_toplines, },
       MAILVAR_TYPEMASK (mailvar_type_number),
-      N_("number of lines to be displayed by `top' or `Top'") },
+      N_("number of lines to be displayed by 'top' or 'Top'") },
     { { mailvar_name_variable_pretty_print, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
       N_("print variables with short descriptions") },
@@ -290,7 +301,7 @@ struct mailvar_symbol mailvar_tab[] =
 
     { { mailvar_name_useragent, },
       MAILVAR_TYPEMASK (mailvar_type_boolean),
-      N_("add the `User-Agent' header to the outgoing messages") },
+      N_("add the 'User-Agent' header to the outgoing messages") },
     { { mailvar_name_xmailer, }, MAILVAR_ALIAS },
 
     { { mailvar_name_mime },
@@ -308,7 +319,8 @@ struct mailvar_symbol mailvar_tab[] =
 
     { { mailvar_name_PID },
       MAILVAR_TYPEMASK (mailvar_type_string) | MAILVAR_RDONLY,
-      N_("PID of this process") },
+      N_("PID of this process"),
+      NULL, init_pid },
 
     /* These will be implemented later */
     { { mailvar_name_onehop, }, MAILVAR_HIDDEN, NULL },
@@ -337,6 +349,19 @@ find_mailvar_symbol (const char *var)
   return NULL;
 }
 
+void
+mailvar_init_variables (void)
+{
+  struct mailvar_symbol *sym;
+  for (sym = mailvar_tab; sym->var.name; sym++)
+    if (!(sym->flags & MAILVAR_ALIAS) && sym->init)
+      {
+	struct mailvar_variable *var;
+	var = mailvar_find_variable (sym->var.name, 1);
+	sym->init (var);
+      }
+}
+
 static void
 print_descr (mu_stream_t out, const char *s, int n,
 	     int doc_col, int rmargin, char *pfx)
@@ -440,7 +465,6 @@ mailvar_find_variable (const char *name, int create)
   return var;
 }
 
-
 /* Retrieve the value of a specified variable of given type.
    The value is stored in the location pointed to by PTR variable.
    VARIABLE and TYPE specify the variable name and type. If the
@@ -516,6 +540,43 @@ mailvar_variable_reset (struct mailvar_variable *var)
   var->set = 0;
 }
 
+static int
+mailvar_variable_init (struct mailvar_variable *var, void *value,
+		       enum mailvar_type type)
+{
+  if (value)
+    {
+      switch (type)
+	{
+	case mailvar_type_number:
+	  var->value.number = *(int*)value;
+	  break;
+
+	case mailvar_type_string:
+	  {
+	    char *p = strdup (value);
+	    if (!p)
+	      {
+		mu_error ("%s", _("Not enough memory"));
+		return 1;
+	      }
+	    var->value.string = p;
+	  }
+	  break;
+
+	case mailvar_type_boolean:
+	  var->value.boolean = *(int*)value;
+	  break;
+
+	default:
+	  abort();
+	}
+      var->set = 1;
+    }
+  var->type = type;
+  return 0;
+}
+
 /* Set environment
    The  mailvar_set() function adds to the mailvar_list the VARIABLE
    with the given VALUE, if VARIABLE does not already exist.
@@ -570,36 +631,8 @@ mailvar_set (const char *variable, void *value, enum mailvar_type type,
   switch (cmd)
     {
     case mailvar_cmd_set:
-      if (value)
-	{
-	  switch (type)
-	    {
-	    case mailvar_type_number:
-	      newvar.value.number = *(int*)value;
-	      break;
-
-	    case mailvar_type_string:
-	      {
-		char *p = strdup (value);
-		if (!p)
-		  {
-		    mu_error ("%s", _("Not enough memory"));
-		    return 1;
-		  }
-		newvar.value.string = p;
-	      }
-	      break;
-
-	    case mailvar_type_boolean:
-	      newvar.value.boolean = *(int*)value;
-	      break;
-
-	    default:
-	      abort();
-	    }
-	  newvar.set = 1;
-	}
-      newvar.type = type;
+      if (mailvar_variable_init (&newvar, value, type))
+	return 1;
       if (sym
 	  && sym->handler
 	  && sym->flags & MAILVAR_TYPEMASK (type)
@@ -623,6 +656,13 @@ mailvar_set (const char *variable, void *value, enum mailvar_type type,
   return 0;
 }
 
+static int
+init_folder (struct mailvar_variable *var)
+{
+  return mailvar_variable_init (var, (void*) mu_folder_directory (),
+				mailvar_type_string);
+}
+
 static int
 set_folder (enum mailvar_cmd cmd, struct mailvar_variable *var)
 {
@@ -657,6 +697,14 @@ set_headline (enum mailvar_cmd cmd, struct mailvar_variable *var)
   return 0;
 }
 
+static int
+init_decode_fallback (struct mailvar_variable *var)
+{
+  return mailvar_variable_init (var,
+		     (void*) mu_iconv_fallback_name (mu_default_fallback_mode),
+		     mailvar_type_string);
+}
+
 static int
 set_decode_fallback (enum mailvar_cmd cmd, struct mailvar_variable *var)
 {
@@ -730,6 +778,29 @@ set_verbose (enum mailvar_cmd cmd, struct mailvar_variable *var)
   return 0;
 }
 
+static int
+init_debug (struct mailvar_variable *var)
+{
+  int rc;
+  mu_stream_t str;
+  mu_transport_t trans[2];
+
+  if ((rc = mu_memory_stream_create (&str, MU_STREAM_RDWR)) != 0)
+    {
+      mu_diag_funcall (MU_DIAG_CRIT, "mu_memory_stream_create", NULL, rc);
+      abort ();
+    }
+  mu_debug_format_spec (str, NULL,
+			MU_DEBUG_FORMAT_COMPRESS | MU_DEBUG_FORMAT_SORT);
+  mu_stream_write (str, "", 1, NULL);
+  mu_stream_ioctl (str, MU_IOCTL_TRANSPORT,
+		   MU_IOCTL_OP_GET,
+		   trans);
+  rc = mailvar_variable_init (var, (char*)trans[0], mailvar_type_string);
+  mu_stream_destroy (&str);
+  return rc;
+}
+
 static int
 set_debug (enum mailvar_cmd cmd, struct mailvar_variable *var)
 {
@@ -792,6 +863,54 @@ set_escape (enum mailvar_cmd cmd, struct mailvar_variable *var)
     }
   return 0;
 }
+
+static int
+init_sendmail (struct mailvar_variable *var)
+{
+  char const *mailer;
+  if (mu_mailer_get_url_default (&mailer))
+    mailer = "sendmail:";
+  return mailvar_variable_init (var, (void*) mailer, mailvar_type_string);
+}
+
+static int
+init_pid (struct mailvar_variable *var)
+{
+  int rc;
+  char *buf;
+  if ((rc = mu_asprintf (&buf, "%lu", (unsigned long) getpid ())) != 0)
+    {
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_asprintf", NULL, rc);
+      return 1;
+    }
+  rc = mailvar_variable_init (var, buf, mailvar_type_string);
+  free (buf);
+  return rc;
+}
+
+static int
+init_screen (struct mailvar_variable *var)
+{
+  int n;
+  char const *p = getenv ("LINES");
+  if (p && p[strspn (p, "0123456789")] == 0)
+    n = atoi (p);
+  else
+    n = util_getlines ();
+  return mailvar_variable_init (var, &n, mailvar_type_number);
+}
+
+static int
+init_columns (struct mailvar_variable *var)
+{
+  int n;
+  char const *p = getenv ("COLUMNS");
+  if (p && p[strspn (p, "0123456789")] == 0)
+    n = atoi (p);
+  else
+    n = util_getcols ();
+  return mailvar_variable_init (var, &n, mailvar_type_number);
+}
 
 size_t
 _mailvar_symbol_count (int set)
@@ -1084,6 +1203,20 @@ describe_symbol (mu_stream_t out, int width, const struct mailvar_symbol *sym)
   mu_stream_printf (out, "\n");
 }
 
+struct vsegm
+{
+  struct mailvar_symbol *sym;
+  int count;
+};
+
+static int
+symcmp (void const *a, void const *b)
+{
+  struct mailvar_symbol * const *sa = a;
+  struct mailvar_symbol * const *sb = b;
+  return strcmp ((*sa)->var.name, (*sb)->var.name);
+}
+
 int
 mail_variable (int argc, char **argv)
 {
@@ -1093,11 +1226,42 @@ mail_variable (int argc, char **argv)
 
   if (argc == 1)
     {
-      struct mailvar_symbol *sym;
+      size_t count;
+      struct mailvar_symbol *sym, **symbuf;
+      size_t i;
 
+      /* Count visible non-alias variables */
+      count = 0;
       for (sym = mailvar_tab; sym->var.name; sym++)
 	if (!(sym->flags & (MAILVAR_HIDDEN|MAILVAR_ALIAS)))
-	  describe_symbol (out, width, sym);
+	  count++;
+
+      /* Collect and sort them. */
+      symbuf = mu_calloc (count, sizeof (symbuf[0]));
+
+      i = 0;
+      for (sym = mailvar_tab; sym->var.name && (sym->flags & MAILVAR_HIDDEN);
+	   sym++);
+      if (sym->var.name == NULL)
+	return 0; /* shouldn't happen */
+      symbuf[0] = sym;
+      for (sym++; sym->var.name; sym++)
+	{
+	  if (!(sym->flags & (MAILVAR_HIDDEN|MAILVAR_ALIAS)))
+	    {
+	      i++;
+	      symbuf[i] = sym;
+	    }
+	}
+
+      qsort (symbuf, count, sizeof (symbuf[0]), symcmp);
+
+      /* Print out the resulting array. */
+      for (i = 0; i < count; i++)
+	if (!(sym->flags & (MAILVAR_HIDDEN|MAILVAR_ALIAS)))
+	  describe_symbol (out, width, symbuf[i]);
+
+      free (symbuf);
     }
   else
     {
