@@ -140,7 +140,7 @@ respond_all (int argc, char **argv, int record_sender)
   
   if (msgset->next)
     {
-      mu_error (_("Can't reply to multiple messages at once"));
+      mu_error (_("Cannot reply to multiple messages at once"));
       status = 1;
     }
   else if (util_get_message (mbox, msgset_msgno (msgset), &msg))
