@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2024 Free Software Foundation, Inc.
+   Copyright (C) 1999-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ set_sender_address (struct mu_parseopt *po, struct mu_option *opt,
       int rc = mu_str_to_c (arg, opt->opt_type, opt->opt_ptr, &errmsg);
       if (rc)
 	{
-	  mu_parseopt_error (po, _("can't set sender address: %s"),
+	  mu_parseopt_error (po, _("cannot set sender address: %s"),
 			     errmsg ? errmsg : mu_strerror (rc));
 	  exit (po->po_exit_error);
 	}
@@ -190,8 +190,7 @@ deliver_to_mailbox (mu_mailbox_t mbox, mu_message_t msg,
   status = mu_mailbox_open (mbox, MU_STREAM_APPEND|MU_STREAM_CREAT);
   if (status != 0)
     {
-      mda_error (_("cannot open mailbox %s: %s"), 
-                    path, mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_open", path, status);
       return EX_TEMPFAIL;
     }
 
@@ -205,8 +204,8 @@ deliver_to_mailbox (mu_mailbox_t mbox, mu_message_t msg,
 
       if (status)
 	{
-	  mda_error (_("cannot lock mailbox `%s': %s"), path,
-		        mu_strerror (status));
+	  mda_error (_("cannot lock mailbox %s: %s"), mu_quotename (path),
+		     mu_strerror (status));
 	  return EX_TEMPFAIL;
 	}
     }
@@ -382,9 +381,8 @@ do_delivery (mu_url_t url, mu_message_t msg, const char *name, char **errp)
 
   if (status)
     {
-      mda_error (_("cannot open mailbox %s: %s"),
-		    mu_url_to_string (url),
-		    mu_strerror (status));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_mailbox_create_from_url",
+		       mu_url_to_string (url), status);
       mu_url_destroy (&url);
       mu_auth_data_free (auth);
       return EX_TEMPFAIL;
