@@ -138,7 +138,7 @@ struct mu_cfg_param lmtp_cfg_param[] = {
        "or socket://<socket-file-name>"),
     N_("url: string") },
   { "reuse-address", mu_c_bool, &reuse_lmtp_address, 0, NULL,
-    N_("Reuse existing address (LMTP mode).  Default is \"yes\".") },
+    N_("Reuse existing address (LMTP mode).  Default is 'yes'.") },
   { "filter", mu_cfg_section, NULL, 0, NULL,
     N_("Add a message filter") },
   { ".server", mu_cfg_section, NULL, 0, NULL,
@@ -149,6 +149,7 @@ struct mu_cfg_param lmtp_cfg_param[] = {
 
 static char *capa[] = {
   "auth",
+  "homedir",
   "debug",
   "logging",
   "mailbox",
@@ -556,8 +557,7 @@ cfun_data (mu_stream_t iostr, char *arg)
 			 MU_STREAM_READ|MU_STREAM_WRTHRU);
   if (rc)
     {
-      mda_error (_("unable to open filter: %s"),
-		    mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_filter_create", "CRLFDOT", rc);
       lmtp_reply (iostr, "450", "4.1.0", "Temporary failure, try again later");
       return 1;
     }
