@@ -48,7 +48,7 @@ set_file (struct mu_parseopt *po, struct mu_option *opt, char const *arg)
 
 static struct mu_option options[] = {
   { "build",        0, NULL, MU_OPTION_DEFAULT,
-    N_("build the draft and quit immediately."),
+    N_("build the draft and quit immediately"),
     mu_c_bool, &build_only },
   { "draftfolder",  0, N_("FOLDER"), MU_OPTION_DEFAULT,
     N_("specify the folder for message drafts"),
@@ -107,8 +107,7 @@ copy_message (mu_mailbox_t mbox, size_t n, const char *file)
   if ((rc = mu_file_stream_create (&out,
 				   file, MU_STREAM_RDWR|MU_STREAM_CREAT)))
     {
-      mu_error (_("cannot open output file \"%s\": %s"),
-		file, mu_strerror (rc));
+      mu_diag_funcall (MU_DIAG_ERROR, "mu_file_stream_create", file, rc);
       mu_stream_destroy (&in);
       return rc;
     }
@@ -120,8 +119,8 @@ copy_message (mu_mailbox_t mbox, size_t n, const char *file)
   
   if (rc)
     {
-      mu_error (_("error copying to \"%s\": %s"),
-		file, mu_strerror (rc));
+      mu_error (_("error copying to %s: %s"),
+		mu_quotename (file), mu_strerror (rc));
     }
   return rc;
 }
@@ -192,8 +191,9 @@ main (int argc, char **argv)
 		  mu_error (_("only one message at a time!"));
 		  return 1;
 		}
+	      // FIXME: allocate storage?
 	      draftmessage =
-		(char*) mu_umaxtostr (0, mh_msgset_first (msgset, RET_UID));
+		(char*) mu_umaxtostr (mh_msgset_first (msgset, RET_UID));
 	      mu_msgset_free (msgset);
 	      mu_mailbox_destroy (&mbox);
 	    }
