@@ -117,8 +117,8 @@ main (int argc, char **argv)
 
   if ((rc = mu_file_stream_create (&in, file, MU_STREAM_RDWR)))
     {
-      mu_error (_("cannot open input file `%s': %s"),
-		file, mu_strerror (rc));
+      mu_error (_("cannot open input file %s: %s"),
+		mu_quotename (file), mu_strerror (rc));
       return 1;
     }
   rc = mu_stream_to_message (in, &msg);
