@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2010-2024 Free Software Foundation, Inc.
+   Copyright (C) 2010-2025 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ send_address_add (mu_address_t *paddr, const char *value)
   rc = mu_address_create (&addr, value);
   if (rc)
     {
-      mu_error (_("%s: %s"), value, mu_strerror (rc));
+      mu_error ("%s: %s", value, mu_strerror (rc));
       exit (1);
     }
   MU_ASSERT (mu_address_union (paddr, addr));
