@@ -66,10 +66,10 @@ pop3d_list (char *arg, struct pop3d_session *sess)
 	      mu_message_size (msg, &size);
 	      mu_message_lines (msg, &lines);
 	      pop3d_outf ("%s %s", 
-                          mu_umaxtostr (0, mesgno), 
-                          mu_umaxtostr (1, size + lines));
+                          mu_umaxtostr_n (0, mesgno), 
+                          mu_umaxtostr_n (1, size + lines));
 	      if (pop3d_xlines)
-		pop3d_outf (" %s", mu_umaxtostr (2, lines));
+		pop3d_outf (" %s", mu_umaxtostr (lines));
 	      pop3d_outf ("\n");
 	    }
 	}
@@ -86,10 +86,10 @@ pop3d_list (char *arg, struct pop3d_session *sess)
       mu_message_size (msg, &size);
       mu_message_lines (msg, &lines);
       pop3d_outf ("+OK %s %s", 
-                  mu_umaxtostr (0, mesgno),
-                  mu_umaxtostr (1, size + lines));
+                  mu_umaxtostr_n (0, mesgno),
+                  mu_umaxtostr_n (1, size + lines));
       if (pop3d_xlines)
-	pop3d_outf (" %s", mu_umaxtostr (2, lines));
+	pop3d_outf (" %s", mu_umaxtostr (lines));
       pop3d_outf ("\n");
     }
 
